@@ -4,8 +4,7 @@ import cwltool.load_tool as load
 from cwltool.context import LoadingContext
 from airflow.configuration import conf
 from airflow.exceptions import AirflowConfigException
-from cwltool.load_tool import (FetcherConstructorType, resolve_tool_uri,
-                               fetch_document, make_tool, validate_document)
+from cwltool.load_tool import (fetch_document, make_tool, resolve_and_validate_document)
 from cwltool.resolver import tool_resolver
 from cwltool.workflow import default_make_tool
 
@@ -31,29 +30,10 @@ def shortname(n):
     return n.split("#")[-1]
 
 
-def load_tool(argsworkflow,              # type: Union[Text, Dict[Text, Any]]
-              loadingContext             # type: LoadingContext
-             ):  # type: (...) -> Process
-
-    document_loader, workflowobj, uri = fetch_document(
-        argsworkflow,
-        resolver=loadingContext.resolver,
-        fetcher_constructor=loadingContext.fetcher_constructor)
-
-    document_loader, avsc_names, _, metadata, uri = validate_document(
-        document_loader, workflowobj, uri,
-        enable_dev=loadingContext.enable_dev,
-        strict=loadingContext.strict,
-        fetcher_constructor=loadingContext.fetcher_constructor,
-        overrides=loadingContext.overrides_list,
-        skip_schemas = True,
-        metadata=loadingContext.metadata)
-
-    return make_tool(document_loader,
-                     avsc_names,
-                     metadata,
-                     uri,
-                     loadingContext)
+def load_tool(argsworkflow, loadingContext):
+    loadingContext, workflowobj, uri = fetch_document(argsworkflow, loadingContext)
+    loadingContext, uri = resolve_and_validate_document(loadingContext, workflowobj, uri, skip_schemas=True)
+    return make_tool(uri, loadingContext)
 
 
 def load_cwl(cwl_file, default_args):
